| Title: | 'Shiny' Components in 'R Markdown' |
|---|---|
| Description: | 'Shiny' components, stored in 'R Markdown' documents. |
| Authors: | Garrick Aden-Buie [aut, cre] (ORCID: <https://orcid.org/0000-0002-7111-0077>) |
| Maintainer: | Garrick Aden-Buie <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1.9000 |
| Built: | 2026-05-26 08:37:01 UTC |
| Source: | https://github.com/gadenbuie/shinyComponents |
Shiny Components are self-contained shiny modules or app components, defined in R Markdown documents.
uiThe UI components. If the component contains only one
unnamed ui chunk, or one ui chunk named ui, then this field is a
method, otherwise it is a list of ui component methods.
serverThe server components. If the component contains only one
unnamed server chunk, or one server chunk named server, then this
field is a method, otherwise it is a list of server component methods.
dependenciesA list of the component's HTML dependencies.
new()
Initialize the Shiny Component from an R Markdown file.
ShinyComponent$new(file)
filePath to the R Markdown document
A new Shiny Component
assets()
The component's CSS, compiled SASS, and JavaScript assets.
ShinyComponent$assets()
A shiny::tagList() containing the component's CSS and
JavaScript assets.
app()
An example app, created from the primary ui and server.
ShinyComponent$app(..., id = NULL, .ui = list(), .server = list())
...Additional variables added into ui and server environments,
in ui, server and app methods. Otherwise, ignored.
idThe component ID, if the component is being used as Shiny module.
.uiA list of arguments to be passed on to the ui() method.
.serverA list of arguments to be passed on to the server()
method.